# galoshes

[![PyPI](https://img.shields.io/pypi/v/galoshes.svg?maxAge=2592000)](https://pypi.python.org/pypi/galoshes)
[![PyPI](https://img.shields.io/pypi/pyversions/galoshes.svg?maxAge=2592000)](https://pypi.python.org/pypi/galoshes)
[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/bsmithyman/galoshes/blob/master/LICENSE)
[![Travis Status](https://travis-ci.org/bsmithyman/galoshes.svg?branch=master)](https://travis-ci.org/bsmithyman/galoshes)
[![Coverage Status](https://coveralls.io/repos/bsmithyman/galoshes/badge.svg?branch=master&service=github)](https://coveralls.io/github/bsmithyman/galoshes?branch=master)
[![Code Issues](https://www.quantifiedcode.com/api/v1/project/65dcfec3894e43d6b6c9413d86ae85e9/badge.svg)](https://www.quantifiedcode.com/app/project/65dcfec3894e43d6b6c9413d86ae85e9)

Tools for bootstrapping classes from key-value stores without getting your feet wet.
